@@ -19,26 +19,8 @@
 #define IWL_22000_SMEM_OFFSET		0x400000
 #define IWL_22000_SMEM_LEN		0xD0000
 
-#define IWL_QU_B_HR_B_FW_PRE		"/*(DEBLOBBED)*/"
-#define IWL_QU_C_HR_B_FW_PRE		"/*(DEBLOBBED)*/"
-#define IWL_QU_B_JF_B_FW_PRE		"/*(DEBLOBBED)*/"
-#define IWL_QU_C_JF_B_FW_PRE		"/*(DEBLOBBED)*/"
-#define IWL_QUZ_A_HR_B_FW_PRE		"/*(DEBLOBBED)*/"
-#define IWL_QUZ_A_JF_B_FW_PRE		"/*(DEBLOBBED)*/"
 #define IWL_CC_A_FW_PRE			"/*(DEBLOBBED)*/"
 
-#define IWL_QU_B_HR_B_MODULE_FIRMWARE(api) \
-	IWL_QU_B_HR_B_FW_PRE /*(DEBLOBBED)*/
-#define IWL_QUZ_A_HR_B_MODULE_FIRMWARE(api) \
-	IWL_QUZ_A_HR_B_FW_PRE /*(DEBLOBBED)*/
-#define IWL_QUZ_A_JF_B_MODULE_FIRMWARE(api) \
-	IWL_QUZ_A_JF_B_FW_PRE /*(DEBLOBBED)*/
-#define IWL_QU_C_HR_B_MODULE_FIRMWARE(api) \
-	IWL_QU_C_HR_B_FW_PRE /*(DEBLOBBED)*/
-#define IWL_QU_B_JF_B_MODULE_FIRMWARE(api) \
-	IWL_QU_B_JF_B_FW_PRE /*(DEBLOBBED)*/
-#define IWL_QU_C_JF_B_MODULE_FIRMWARE(api) \
-	IWL_QU_C_JF_B_FW_PRE /*(DEBLOBBED)*/
 #define IWL_CC_A_MODULE_FIRMWARE(api)			\
 	IWL_CC_A_FW_PRE /*(DEBLOBBED)*/
 
